@@ -1,6 +1,6 @@
 package App::Info::HTTPD::Apache;
 
-# $Id: Apache.pm,v 1.39 2003/08/26 01:50:20 david Exp $
+# $Id: Apache.pm 817 2004-11-03 17:55:05Z theory $
 
 =head1 NAME
 
@@ -44,7 +44,8 @@ use App::Info::HTTPD;
 use App::Info::Util;
 use vars qw(@ISA $VERSION);
 @ISA = qw(App::Info::HTTPD);
-$VERSION = '0.22';
+$VERSION = '0.26';
+use constant WIN32 => $^O eq 'MSWin32';
 
 my $u = App::Info::Util->new;
 
@@ -142,6 +143,7 @@ sub new {
          /sw/sbin));
 
     my @exes = qw(httpd apache-perl apache);
+    if (WIN32) { $_ .= ".exe" for @exes }
 
     if (my $exe = $u->first_cat_exe(\@exes, @paths)) {
         # We found httpd. Confirm.
@@ -516,6 +518,14 @@ my $get_compile_settings = sub {
             $_ =~ s/"$//;
             my ($k, $v) = split /\s*=\s*"/, $_;
             $self->{lc $k} = $v;
+            if (WIN32) {
+                if ($k eq 'SUEXEC_BIN') {
+                    $self->{lc $k} = 0;
+                } elsif ($k eq 'HTTPD_ROOT') {
+                    $self->{lc $k} =
+                      join('\\', (split /\\/, $self->{exe} )[0 .. 1]);
+                 }
+            }
         } elsif (/-D/) {
             $_ =~ s/^-D\s+//;
             $self->{lc $_} = 1;
@@ -1294,7 +1304,7 @@ L<http://perl.apache.org/> is the mod_perl home page.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2003, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2004, David Wheeler. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
